import * as i1 from '@angular/common/http';
import { HttpClient, HttpErrorResponse, HttpClientModule } from '@angular/common/http';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { catchError } from 'rxjs';
import * as i2 from '@angular/router';

class SalesOrderHttpInterceptorHandler {
    constructor(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    handle(req) {
        return this.interceptor.intercept(req, this.next);
    }
}
class SalesOrderHandlerService {
    constructor(backend, injector, interceptors) {
        this.backend = backend;
        this.injector = injector;
        this.interceptors = interceptors;
        this.chain = null;
    }
    handle(req) {
        if (this.chain === null) {
            const interceptors = this.injector.get(this.interceptors, []);
            this.chain = interceptors.reduceRight((next, interceptor) => new SalesOrderHttpInterceptorHandler(next, interceptor), this.backend);
        }
        return this.chain.handle(req);
    }
}
const SALES_ORDER_HTTP_INTERCEPTORS = new InjectionToken('SALES_ORDER_HTTP_INTERCEPTORS');
class SalesOrderHttpService extends HttpClient {
    constructor(backend, injector) {
        super(new SalesOrderHandlerService(backend, injector, SALES_ORDER_HTTP_INTERCEPTORS));
        this.injector = injector;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderHttpService, deps: [{ token: i1.HttpBackend }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderHttpService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderHttpService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpBackend }, { type: i0.Injector }] });
class SalesOrderAuthInterceptor {
    constructor(moduleConfig, router) {
        this.moduleConfig = moduleConfig;
        this.router = router;
    }
    intercept(req, next) {
        const authToken = localStorage.getItem('tokenGlobal');
        const { baseUrl } = this.moduleConfig;
        const update = {
            url: `${baseUrl}/${req.url}`,
        };
        if (authToken) {
            update.headers = req.headers.set('Authorization', `Bearer ${authToken}`);
        }
        const authReq = req.clone(update);
        return next.handle(authReq).pipe(catchError((error) => {
            if (error instanceof HttpErrorResponse && error.status === 401) {
                this.router.navigate(['auth', 'login']);
            }
            throw error;
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderAuthInterceptor, deps: [{ token: SALES_ORDER_MODULE_CONFIG }, { token: i2.Router }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderAuthInterceptor }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SalesOrderAuthInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [SALES_ORDER_MODULE_CONFIG]
                }] }, { type: i2.Router }] });

class CbmSalesOrderService {
    constructor(http) {
        this.http = http;
    }
    list(params) {
        return this.http.get('', {
            params: params,
        });
    }
    getOne(id) {
        return this.http.get(id);
    }
    save(data) {
        return this.http.post('', data);
    }
    update(id, data) {
        return this.http.put(id, data);
    }
    changeStatus(id, data) {
        return this.http.put(`change-status/${id}`, data);
    }
    sendEmail(id, params) {
        return this.http.get(`sent-email/${id}`, {
            params: params,
        });
    }
    downloadExcel(params) {
        return this.http.get('download/excel', {
            params: params,
            observe: 'response',
            responseType: 'blob',
        });
    }
    downloadIndividualPdf(id) {
        return this.http.get(`download/pdf/individual/${id}`, {
            observe: 'response',
            responseType: 'blob',
        });
    }
    downloadIndividualExcel(id) {
        return this.http.get(`download/excel/individual/${id}`, {
            observe: 'response',
            responseType: 'blob',
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderService, deps: [{ token: SalesOrderHttpService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: SalesOrderHttpService }] });

class CbmSalesOrderRepository {
    constructor(service) {
        this.service = service;
    }
    list(params) {
        return this.service.list(params);
    }
    getOne(id) {
        return this.service.getOne(id);
    }
    save(data) {
        return this.service.save(data);
    }
    update(id, data) {
        return this.service.update(id, data);
    }
    changeStatus(id, data) {
        return this.service.changeStatus(id, data);
    }
    sendEmail(id, params) {
        return this.service.sendEmail(id, params);
    }
    downloadExcel(params) {
        return this.service.downloadExcel(params);
    }
    downloadIndividualPdf(id) {
        return this.service.downloadIndividualPdf(id);
    }
    downloadIndividualExcel(id) {
        return this.service.downloadIndividualExcel(id);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderRepository, deps: [{ token: CbmSalesOrderService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderRepository }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderRepository, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: CbmSalesOrderService }] });

const SALES_ORDER_MODULE_CONFIG = new InjectionToken('SALES_ORDER_MODULE_CONFIG');
class CbmSalesOrderModule {
    static forRoot(config) {
        return {
            ngModule: CbmSalesOrderModule,
            providers: [
                SalesOrderAuthInterceptor,
                {
                    provide: SALES_ORDER_MODULE_CONFIG,
                    useValue: config,
                },
                {
                    provide: SALES_ORDER_HTTP_INTERCEPTORS,
                    useClass: SalesOrderAuthInterceptor,
                    multi: true,
                },
                SalesOrderHttpService,
                CbmSalesOrderService,
                CbmSalesOrderRepository,
            ],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderModule, imports: [HttpClientModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderModule, imports: [HttpClientModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmSalesOrderModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [HttpClientModule],
                }]
        }] });

/*
 * Public API Surface of sales-order-repository
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CbmSalesOrderModule, CbmSalesOrderRepository, CbmSalesOrderService, SALES_ORDER_MODULE_CONFIG };
//# sourceMappingURL=g2-common-sales-order-repository.mjs.map
